@@ -28,7 +28,7 @@ class BaseJobCommand(BaseCommand):
 
 
 @six.add_metaclass(abc.ABCMeta)
-class BaseCreateJobCommandMixin(object):
+class BaseCreateJobCommandMixin(BaseJobCommand):
     SPINNER_MESSAGE = "Creating new job"
     CREATE_SUCCESS_MESSAGE_TEMPLATE = "New job created with ID: {}"
 
@@ -45,9 +45,8 @@ class BaseCreateJobCommandMixin(object):
         self.logger.log(self.CREATE_SUCCESS_MESSAGE_TEMPLATE.format(job_id))
         self.logger.log(self.get_instance_url(job_id))
 
-    @staticmethod
-    def get_instance_url(instance_id):
-        url = concatenate_urls(config.config.WEB_URL, "jobs/{}".format(instance_id))
+    def get_instance_url(self, instance_id):
+        url = concatenate_urls(config.config.WEB_URL, "{}/jobs/{}".format(self.get_namespace(), instance_id))
         return url
 
     def _handle_workspace(self, instance_dict):
@@ -158,7 +157,7 @@ class JobLogsCommand(LogsCommandMixin, BaseJobCommand):
     ENTITY = "Job"
 
 
-class CreateJobCommand(BaseCreateJobCommandMixin, BaseJobCommand):
+class CreateJobCommand(BaseCreateJobCommandMixin):
 
     def _create(self, json_, data):
         # because ignore_files is used by workspace handlers and not needed anymore (will fail if not "popped")
